@@ -3,6 +3,9 @@
 from enum import Enum
 
 class SampleMethod(str, Enum):
+    """
+    Enum for the possible Monte-Carlo sampling methods.
+    """
     RANDOM          = 'random'
     SOBOL           = 'sobol'
     SOBOL_RANDOM    = 'sobol_random'
@@ -12,12 +15,19 @@ class SampleMethod(str, Enum):
 
 
 class MCFunctions(str, Enum):
+    """
+    Enum for the three required user functions.
+    """
     PREPROCESS  = 'preprocess'
     RUN         = 'run'
     POSTPROCESS = 'postprocess'
 
 
 class StatBound(str, Enum):
+    """
+    Enum for possible statistical bounds. Note that not all of these may be
+    valid for a given statistical function.
+    """
     NEAREST        = 'nearest'
     BOTH           = 'both'
     ALL            = 'all'
@@ -28,21 +38,35 @@ class StatBound(str, Enum):
 
 
 class VarStat(str, Enum):
+    """
+    Enum for the variable statistics functions.
+    """
     MAX         = 'max'
     MIN         = 'min'
     MEDIAN      = 'median'
     MEAN        = 'mean'
     GEOMEAN     = 'geomean'
     MODE        = 'mode'
-    SIGMAP      = 'sigmaP'
+    SIGMA       = 'sigma'
     GAUSSIANP   = 'gaussianP'
     ORDERSTATTI = 'orderstatTI'
     ORDERSTATP  = 'orderstatP'
 
 
 class VarStatSide(str, Enum):
+    """
+    Enum for the variable statistics 'side' (see documentation for each varstat
+    function).
+    """
     HIGH = 'high'
     LOW  = 'low'
     BOTH = 'both'
     ALL  = 'all'
-    
\ No newline at end of file
+
+
+class PlotOrientation(str, Enum):
+    """
+    Enum for the plotting functions orientation.
+    """
+    VERTICAL   = 'vertical'
+    HORIZONTAL = 'horizontal'
