@@ -3,40 +3,61 @@
 import scipy.stats
 import numpy as np
 from monaco.MCEnums import StatBound
-'''
-Reference:
-Hahn, Gerald J., and Meeker, William Q. "Statistical Intervals: A Guide for 
-    Practitioners." Germany, Wiley, 1991.
-'''
 
 
 def order_stat_TI_n(k     : int, 
-                    p     : float, # 0 < p < 1 
-                    c     : float, # 0 < c < 1
+                    p     : float,
+                    c     : float,
                     nmax  : int       = int(1e7), 
-                    bound : StatBound = StatBound.TWOSIDED, # '1-sided' or '2-sided'
+                    bound : StatBound = StatBound.TWOSIDED,
                     ) -> int:
-    '''
-    Order Statistic Tolerance Interval, find n
-    This function returns the number of cases n necessary to say that the true 
-    result of a measurement x will be bounded by the k'th order statistic with 
-    a probability p and confidence c. Variables l and u below indicate lower 
+    """
+    For an Order Statistic Tolerance Interval, find the minimum n from k, p,
+    and c
+
+    Notes
+    -----
+    This function returns the number of cases n necessary to say that the true
+    result of a measurement x will be bounded by the k'th order statistic with
+    a probability p and confidence c. Variables l and u below indicate lower
     and upper indices of the order statistic.
     
-    For example, if I want to use my 2nd highest measurement as a bound on 99% 
+    For example, if I want to use my 2nd highest measurement as a bound on 99%
     of all future samples with 90% confidence:
         n = order_stat_TI_n(k=2, p=0.99, c=0.90, bound='1-sided') = 389
-    The 388th value of x when sorted from low to high, or sorted(x)[-2], will 
+    The 388th value of x when sorted from low to high, or sorted(x)[-2], will
     bound the upper end of the measurement with P99/90. 
     
-    '2-sided' gives the result for the measurement lying between the k'th lowest 
-    and k'th highest measurements. If we run the above function with 
-    bound='2-sided', then n = 668, and we can say that the true measurement lies 
+    '2-sided' gives the result for the measurement lying between the k'th lowest
+    and k'th highest measurements. If we run the above function with
+    bound='2-sided', then n = 668, and we can say that the true measurement lies
     between sorted(x)[1] and sorted(x)[-2] with P99/90.
     
-    See chapter 5 of Reference at the top of this file for statistical 
-    background.
-    '''
+    See chapter 5 of Reference [1]_ for statistical background.
+
+    Parameters
+    ----------
+    k : int
+        The k'th order statistic.
+    p : float (0 < p < 1)
+        The percent covered by the tolerance interval.
+    c : float (0 < c < 1)
+        The confidence of the interval bound.
+    nmax : int, default: 1e7
+        The maximum number of draws. Hard limit of 2**1000.
+    bound : monaco.MCEnums.StatBound, default: '2-sided'
+        The statistical bound, either '1-sided' or '2-sided'.
+    
+    Returns
+    -------
+    n : int
+        The number of samples necessary to meet the constraints.
+    
+    References
+    ----------
+    .. [1] Hahn, Gerald J., and Meeker, William Q. "Statistical Intervals: A
+       Guide for Practitioners." Germany, Wiley, 1991.
+    """
     order_stat_var_check(p=p, k=k, c=c, nmax=nmax)
     
     if bound == StatBound.TWOSIDED:
@@ -70,11 +91,33 @@ def order_stat_TI_n(k     : int,
 
 def order_stat_TI_p(n     : int, 
                     k     : int, 
-                    c     : float, # 0 < c < 1 
+                    c     : float,
                     ptol  : float     = 1e-9, 
-                    bound : StatBound = StatBound.TWOSIDED, # '1-sided' or '2-sided'
+                    bound : StatBound = StatBound.TWOSIDED,
                     ) -> float:
-    # Order Statistic Tolerance Interval, find p
+    """
+    For an Order Statistic Tolerance Interval, find the maximum p from n, k,
+    and c.
+
+    Parameters
+    ----------
+    n : int
+        The number of samples.
+    k : int
+        The k'th order statistic.
+    c : float (0 < c < 1)
+        The confidence of the interval bound.
+    ptol : float, default: 1e-9
+        The absolute tolerance on determining p.
+    bound : monaco.MCEnums.StatBound, default: '2-sided'
+        The statistical bound, either '1-sided' or '2-sided'.
+    
+    Returns
+    -------
+    p : float (0 < p < 1)
+        The percent which the tolerance interval covers corresponding to the
+        input constraints. 
+    """
     order_stat_var_check(n=n, k=k, c=c)
     
     if bound == StatBound.TWOSIDED:
@@ -103,11 +146,30 @@ def order_stat_TI_p(n     : int,
 
 
 def order_stat_TI_k(n     : int, 
-                    p     : float, # 0 < p < 1 
-                    c     : float, # 0 < p < 1
-                    bound : StatBound = StatBound.TWOSIDED, # '1-sided' or '2-sided'
+                    p     : float,
+                    c     : float,
+                    bound : StatBound = StatBound.TWOSIDED,
                     ) -> int:
-    # Order Statistic Tolerance Interval, find maximum k
+    """
+    For an Order Statistic Tolerance Interval, find the maximum k from n, p,
+    and c.
+
+    Parameters
+    ----------
+    n : int
+        The number of samples.
+    p : float (0 < p < 1)
+        The percent covered by the tolerance interval.
+    c : float (0 < c < 1)
+        The confidence of the interval bound.
+    bound : monaco.MCEnums.StatBound, default: '2-sided'
+        The statistical bound, either '1-sided' or '2-sided'.
+    
+    Returns
+    -------
+    k : int
+        The k'th order statistic. 
+    """
     order_stat_var_check(n=n, p=p, c=c)
     
     if bound == StatBound.TWOSIDED:
@@ -143,12 +205,31 @@ def order_stat_TI_k(n     : int,
        
 
 
-def order_stat_TI_c(n     : int, 
+def order_stat_TI_c(n     : int,
                     k     : int,
-                    p     : float, # 0 < p < 1 
-                    bound : StatBound = StatBound.TWOSIDED, # '1-sided' or '2-sided'
+                    p     : float,
+                    bound : StatBound = StatBound.TWOSIDED,
                     ) -> float:
-    # Order Statistic Tolerance Interval, find c
+    """
+    For an Order Statistic Tolerance Interval, find the maximum c from n, k,
+    and p.
+
+    Parameters
+    ----------
+    n : int
+        The number of samples.
+    k : int
+        The k'th order statistic.
+    p : float (0 < p < 1)
+        The percent covered by the tolerance interval.
+    bound : monaco.MCEnums.StatBound, default: '2-sided'
+        The statistical bound, either '1-sided' or '2-sided'.
+    
+    Returns
+    -------
+    c : float (0 < c < 1)
+        The confidence of the interval bound.
+    """
     order_stat_var_check(n=n, p=p, k=k)
     
     if bound == StatBound.TWOSIDED:
@@ -165,14 +246,17 @@ def order_stat_TI_c(n     : int,
 
 
 
-def order_stat_P_n(k     : int, 
-                   P     : float,           # 0 < P < 1 
-                   c     : float,           # 0 < c < 1
-                   nmax  : int = int(1e7), 
-                   bound : StatBound = StatBound.TWOSIDED, # '1-sided' or '2-sided'
+def order_stat_P_n(k     : int,
+                   P     : float,
+                   c     : float,
+                   nmax  : int = int(1e7),
+                   bound : StatBound = StatBound.TWOSIDED,
                    ) -> int:
-    '''
-    Order Statistic Percentile, find n
+    """
+    Order Statistic Percentile, find minimum n from k, P, and c.
+
+    Notes
+    -----
     This function returns the number of cases n necessary to say that the true 
     Pth percentile located at or between indices iPl and iPu of a measurement x
     will be bounded by the k'th order statistic with confidence c. 
@@ -182,17 +266,39 @@ def order_stat_P_n(k     : int,
         n = order_stat_P_n(k=5, P=0.50, c=0.90, bound='2-sided') = 38
         iPl = np.floor(P*(n + 1)) = 19
         iPu = np.ceil(P*(n + 1)) = 20
-    The 19-5 = 14th and 20+5= 25th values of x when sorted from low to high, 
-    or [sorted(x)[13], sorted(x)[24]] will bound the 50th percentile with 90%
-    confidence. 
+    The 19-5 = 14th and 20+5= 25th values of x when sorted from low to high, or
+    [sorted(x)[13], sorted(x)[24]] will bound the 50th percentile with 90%
+    confidence.
     
     '2-sided' gives the upper and lower bounds. '1-sided lower' and 
     '1-sided upper' give the respective lower or upper bound of the Pth 
     percentile over the entire rest of the distribution. 
     
-    See chapter 5 of Reference at the top of this file for statistical 
-    background.
-    '''
+    See chapter 5 of Reference [1]_ for statistical background.
+
+    Parameters
+    ----------
+    k : int
+        The k'th order statistic.
+    P : float (0 < P < 1)
+        The target percentile.
+    c : float (0 < c < 1)
+        The confidence of the interval bound.
+    nmax : int, default: 1e7
+        The maximum number of draws. Hard limit of 2**1000.
+    bound : monaco.MCEnums.StatBound, default: '2-sided'
+        The statistical bound, '1-sided upper', '1-sided lower', or '2-sided'.
+    
+    Returns
+    -------
+    n : int
+        The number of samples necessary to meet the constraints.
+
+    References
+    ----------
+    .. [1] Hahn, Gerald J., and Meeker, William Q. "Statistical Intervals: A
+       Guide for Practitioners." Germany, Wiley, 1991.
+    """
     order_stat_var_check(p=P, k=k, c=c, nmax=nmax)
     
     # use bisection to get minimum n (secant method is unstable due to flat portions of curve)
@@ -220,7 +326,6 @@ def order_stat_P_n(k     : int,
     else:
         raise ValueError(f"{bound=} must be {StatBound.ONESIDED_UPPER}, {StatBound.ONESIDED_LOWER}, or {StatBound.TWOSIDED}")
 
-
     for i in range(maxsteps):
         step = (n[1]-n[0])/2
         if step < 1:
@@ -246,12 +351,32 @@ def order_stat_P_n(k     : int,
 
 
 
-def order_stat_P_k(n     : int, 
-                   P     : float,           # 0 < P < 1 
-                   c     : float,           # 0 < c < 1
-                   bound : StatBound = StatBound.TWOSIDED, # '1-sided upper', '1-sided lower', or '2-sided'
+def order_stat_P_k(n     : int,
+                   P     : float,
+                   c     : float,
+                   bound : StatBound = StatBound.TWOSIDED,
                    ) -> int:
-    # Order Statistic Percentile, find maximum k
+    """
+    For an Order Statistic Percentile, find the maximum p from n, k, and c.
+
+    Parameters
+    ----------
+    n : int
+        The number of samples.
+    P : float (0 < P < 1)
+        The target percentile.
+    c : float (0 < c < 1)
+        The confidence of the interval bound.
+    ptol : float, default: 1e-9
+        The absolute tolerance on determining p.
+    bound : monaco.MCEnums.StatBound, default: '2-sided'
+        The statistical bound, '1-sided upper', '1-sided lower', or '2-sided'.
+    
+    Returns
+    -------
+    k : int
+        The k'th order statistic meeting the input constraints. 
+    """
     order_stat_var_check(n=n, p=P, c=c)
     
     (iPl, iP, iPu) = get_iP(n, P)    
@@ -309,10 +434,28 @@ def order_stat_P_k(n     : int,
 
 def order_stat_P_c(n     : int, 
                    k     : int, 
-                   P     : float,           # 0 < P < 1
-                   bound : StatBound = StatBound.TWOSIDED, # '1-sided upper', '1-sided lower', or '2-sided'
+                   P     : float,
+                   bound : StatBound = StatBound.TWOSIDED,
                    ) -> float:
-    # Order Statistic Percentile, find c
+    """
+    For an Order Statistic percentile, find the maximum c from n, k, and P.
+
+    Parameters
+    ----------
+    n : int
+        The number of samples.
+    k : int
+        The k'th order statistic.
+    P : float (0 < P < 1)
+        The target percentile.
+    bound : monaco.MCEnums.StatBound, default: '2-sided'
+        The statistical bound, '1-sided upper', '1-sided lower', or '2-sided'.
+    
+    Returns
+    -------
+    c : float (0 < c < 1)
+        The confidence of the interval bound.
+    """
     order_stat_var_check(n=n, p=P, k=k)
 
     (iPl, iP, iPu) = get_iP(n, P)    
@@ -336,34 +479,84 @@ def order_stat_P_c(n     : int,
 
 
 
-def EPYP(n : int, 
-         l : int, 
-         u : int, 
-         p : float, # 0 < p < 1
+def EPYP(n : int,
+         l : int,
+         u : int,
+         p : float,
          ) -> float:
-    # Estimated Probabiliity for the Y'th Percentile, see Chp. 5.2 of Reference
+    """
+    Estimated Probabiliity for the Y'th Percentile, see Chp. 5.2 of Reference.
+
+    Parameters
+    ----------
+    n : int
+        TODO Description
+    l : int
+        TODO Description
+    u : int
+        TODO Description
+    p : float (0 < p < 1)
+        TODO Description
+
+    Returns
+    -------
+    c : float (0 < c < 1)
+        TODO Description
+    """
     order_stat_var_check(n=n, l=l, u=u, p=p)
     c = scipy.stats.binom.cdf(u-1, n, p) - scipy.stats.binom.cdf(l-1, n, p)
     return c
 
 
 
-def EPTI(n : int, 
-         l : int, 
-         u : int, 
-         p : float, # 0 < p < 1
+def EPTI(n : int,
+         l : int,
+         u : int,
+         p : float,
          ) -> float:
-    # Estimated Probabiliity for a Tolerance Interval, see Chp. 5.3 of Reference
+    """
+    Estimated Probabiliity for a Tolerance Interval, see Chp. 5.3 of Reference
+
+    Parameters
+    ----------
+    n : int
+        TODO Description
+    l : int
+        TODO Description
+    u : int
+        TODO Description
+    p : float (0 < p < 1)
+        TODO Description
+
+    Returns
+    -------
+    c : float (0 < c < 1)
+        TODO Description
+    """
     order_stat_var_check(n=n, l=l, u=u, p=p)
     c = scipy.stats.binom.cdf(u-l-1, n, p)
     return c
 
 
 
-def get_iP(n : int, 
-           P : float, # 0 < P < 1
+def get_iP(n : int,
+           P : float,
            ) -> tuple[int, int, int]:
-    # Index of Percentile (1-based indexing)
+    """
+    Get the index of Percentile (1-based indexing)
+
+    Parameters
+    ----------
+    n : int
+        Number of samples
+    P : float (0 < P < 1)
+        Target percentile
+
+    Returns
+    -------
+    (iPl, iP, iPu) : (int, int, int)
+        Lower, closest, and upper index of the percentile.
+    """
     iP = P*(n + 1) 
     iPl = int(np.floor(iP))
     iPu = int(np.ceil(iP))
@@ -380,6 +573,9 @@ def order_stat_var_check(n : int = None,
                          c : float = None, 
                          nmax : int = None
                          ) -> None:
+    """
+    Check the validity of the inputs to the order statistic functions.
+    """
     if n is not None and n < 1:
         raise ValueError(f'{n=} must be >= 1')
     if l is not None and l < 0:
